Action class

Describes the actions associated with a rule.

Constructors

Action({CloudwatchAlarmAction? cloudwatchAlarm, CloudwatchLogsAction? cloudwatchLogs, CloudwatchMetricAction? cloudwatchMetric, DynamoDBAction? dynamoDB, DynamoDBv2Action? dynamoDBv2, ElasticsearchAction? elasticsearch, FirehoseAction? firehose, HttpAction? http, IotAnalyticsAction? iotAnalytics, IotEventsAction? iotEvents, IotSiteWiseAction? iotSiteWise, KafkaAction? kafka, KinesisAction? kinesis, LambdaAction? lambda, RepublishAction? republish, S3Action? s3, SalesforceAction? salesforce, SnsAction? sns, SqsAction? sqs, StepFunctionsAction? stepFunctions, TimestreamAction? timestream})
Action.fromJson(Map<String, dynamic> json)
factory

Properties

cloudwatchAlarm → CloudwatchAlarmAction?
Change the state of a CloudWatch alarm.
final
cloudwatchLogs → CloudwatchLogsAction?
Send data to CloudWatch Logs.
final
cloudwatchMetric → CloudwatchMetricAction?
Capture a CloudWatch metric.
final
dynamoDB → DynamoDBAction?
Write to a DynamoDB table.
final
dynamoDBv2 → DynamoDBv2Action?
Write to a DynamoDB table. This is a new version of the DynamoDB action. It allows you to write each attribute in an MQTT message payload into a separate DynamoDB column.
final
elasticsearch → ElasticsearchAction?
Write data to an Amazon Elasticsearch Service domain.
final
firehose → FirehoseAction?
Write to an Amazon Kinesis Firehose stream.
final
hashCode → int
The hash code for this object.
no setterinherited
http → HttpAction?
Send data to an HTTPS endpoint.
final
iotAnalytics → IotAnalyticsAction?
Sends message data to an AWS IoT Analytics channel.
final
iotEvents → IotEventsAction?
Sends an input to an AWS IoT Events detector.
final
iotSiteWise → IotSiteWiseAction?
Sends data from the MQTT message that triggered the rule to AWS IoT SiteWise asset properties.
final
kafka → KafkaAction?
Send messages to an Amazon Managed Streaming for Apache Kafka (Amazon MSK) or self-managed Apache Kafka cluster.
final
kinesis → KinesisAction?
Write data to an Amazon Kinesis stream.
final
lambda → LambdaAction?
Invoke a Lambda function.
final
republish → RepublishAction?
Publish to another MQTT topic.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3 → S3Action?
Write to an Amazon S3 bucket.
final
salesforce → SalesforceAction?
Send a message to a Salesforce IoT Cloud Input Stream.
final
sns → SnsAction?
Publish to an Amazon SNS topic.
final
sqs → SqsAction?
Publish to an Amazon SQS queue.
final
stepFunctions → StepFunctionsAction?
Starts execution of a Step Functions state machine.
final
timestream → TimestreamAction?
The Timestream rule action writes attributes (measures) from an MQTT message into an Amazon Timestream table. For more information, see the Timestream topic rule action documentation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited