AddThingsToThingGroupParams class

Parameters used when defining a mitigation action that move a set of things to a thing group.

Constructors

AddThingsToThingGroupParams({required List<String> thingGroupNames, bool? overrideDynamicGroups})
AddThingsToThingGroupParams.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
overrideDynamicGroups → bool?
Specifies if this mitigation action can move the things that triggered the mitigation action even if they are part of one or more dynamic thing groups.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thingGroupNames → List<String>
The list of groups to which you want to add the things that triggered the mitigation action. You can add a thing to a maximum of 10 groups, but you can't add a thing to more than one group in the same hierarchy.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited