AlertTarget class

A structure containing the alert target ARN and the role ARN.

Constructors

AlertTarget({required String alertTargetArn, required String roleArn})
AlertTarget.fromJson(Map<String, dynamic> json)
factory

Properties

alertTargetArn → String
The Amazon Resource Name (ARN) of the notification target to which alerts are sent.
final
hashCode → int
The hash code for this object.
no setterinherited
roleArn → String
The ARN of the role that grants permission to send alerts to the notification target.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited