AssetPropertyVariant class

Contains an asset property value (of a single type).

Constructors

AssetPropertyVariant({String? booleanValue, String? doubleValue, String? integerValue, String? stringValue})
AssetPropertyVariant.fromJson(Map<String, dynamic> json)
factory

Properties

booleanValue → String?
Optional. A string that contains the boolean value (true or false) of the value entry. Accepts substitution templates.
final
doubleValue → String?
Optional. A string that contains the double value of the value entry. Accepts substitution templates.
final
hashCode → int
The hash code for this object.
no setterinherited
integerValue → String?
Optional. A string that contains the integer value of the value entry. Accepts substitution templates.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String?
Optional. The string value of the value entry. Accepts substitution templates.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited