AssociateTargetsWithJobResponse class

Constructors

AssociateTargetsWithJobResponse({String? description, String? jobArn, String? jobId})
AssociateTargetsWithJobResponse.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
A short text description of the job.
final
hashCode → int
The hash code for this object.
no setterinherited
jobArn → String?
An ARN identifying the job.
final
jobId → String?
The unique identifier you assigned to this job when it was created.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited