AuditMitigationActionsTaskMetadata class

Information about an audit mitigation actions task that is returned by ListAuditMitigationActionsTasks.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → DateTime?
The time at which the audit mitigation actions task was started.
final
taskId → String?
The unique identifier for the task.
final
taskStatus → AuditMitigationActionsTaskStatus?
The current state of the audit mitigation actions task.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited