AuditMitigationActionsTaskTarget class

Used in MitigationActionParams, this information identifies the target findings to which the mitigation actions are applied. Only one entry appears.

Constructors

AuditMitigationActionsTaskTarget({Map<String, List<String>>? auditCheckToReasonCodeFilter, String? auditTaskId, List<String>? findingIds})
AuditMitigationActionsTaskTarget.fromJson(Map<String, dynamic> json)
factory

Properties

auditCheckToReasonCodeFilter → Map<String, List<String>>?
Specifies a filter in the form of an audit check and set of reason codes that identify the findings from the audit to which the audit mitigation actions task apply.
final
auditTaskId → String?
If the task will apply a mitigation action to findings from a specific audit, this value uniquely identifies the audit.
final
findingIds → List<String>?
If the task will apply a mitigation action to one or more listed findings, this value uniquely identifies those findings.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited