AuditNotificationTarget class

Information about the targets to which audit notifications are sent.

Constructors

AuditNotificationTarget({bool? enabled, String? roleArn, String? targetArn})
AuditNotificationTarget.fromJson(Map<String, dynamic> json)
factory

Properties

enabled → bool?
True if notifications to the target are enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
roleArn → String?
The ARN of the role that grants permission to send notifications to the target.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetArn → String?
The ARN of the target (SNS topic) to which audit notifications are sent.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited