AuthResult class

The authorizer result.

Constructors

AuthResult({Allowed? allowed, AuthDecision? authDecision, AuthInfo? authInfo, Denied? denied, List<String>? missingContextValues})
AuthResult.fromJson(Map<String, dynamic> json)
factory

Properties

allowed → Allowed?
The policies and statements that allowed the specified action.
final
authDecision → AuthDecision?
The final authorization decision of this scenario. Multiple statements are taken into account when determining the authorization decision. An explicit deny statement can override multiple allow statements.
final
authInfo → AuthInfo?
Authorization information.
final
denied → Denied?
The policies and statements that denied the specified action.
final
hashCode → int
The hash code for this object.
no setterinherited
missingContextValues → List<String>?
Contains any missing context values found while evaluating policy.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited