AuthorizerConfig class

An object that specifies the authorization service for a domain.

Constructors

AuthorizerConfig({bool? allowAuthorizerOverride, String? defaultAuthorizerName})
AuthorizerConfig.fromJson(Map<String, dynamic> json)
factory

Properties

allowAuthorizerOverride → bool?
A Boolean that specifies whether the domain configuration's authorization service can be overridden.
final
defaultAuthorizerName → String?
The name of the authorization service for a domain configuration.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited