BehaviorModelTrainingSummary class

The summary of an ML Detect behavior model.

Constructors

BehaviorModelTrainingSummary({String? behaviorName, double? datapointsCollectionPercentage, DateTime? lastModelRefreshDate, ModelStatus? modelStatus, String? securityProfileName, DateTime? trainingDataCollectionStartDate})
BehaviorModelTrainingSummary.fromJson(Map<String, dynamic> json)
factory

Properties

behaviorName → String?
The name of the behavior.
final
datapointsCollectionPercentage → double?
The percentage of datapoints collected.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModelRefreshDate → DateTime?
The date the model was last refreshed.
final
modelStatus → ModelStatus?
The status of the behavior model.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityProfileName → String?
The name of the security profile.
final
trainingDataCollectionStartDate → DateTime?
The date a training model started collecting data.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited