CodeSigning class

Describes the method to use when code signing a file.

Constructors

CodeSigning({String? awsSignerJobId, CustomCodeSigning? customCodeSigning, StartSigningJobParameter? startSigningJobParameter})
CodeSigning.fromJson(Map<String, dynamic> json)
factory

Properties

awsSignerJobId → String?
The ID of the AWSSignerJob which was created to sign the file.
final
customCodeSigning → CustomCodeSigning?
A custom method for code signing a file.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startSigningJobParameter → StartSigningJobParameter?
Describes the code-signing job.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited