CreateDynamicThingGroupResponse class

Constructors

CreateDynamicThingGroupResponse({String? indexName, String? queryString, String? queryVersion, String? thingGroupArn, String? thingGroupId, String? thingGroupName})
CreateDynamicThingGroupResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
indexName → String?
The dynamic thing group index name.
final
queryString → String?
The dynamic thing group search query string.
final
queryVersion → String?
The dynamic thing group query version.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thingGroupArn → String?
The dynamic thing group ARN.
final
thingGroupId → String?
The dynamic thing group ID.
final
thingGroupName → String?
The dynamic thing group name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited