CreateMitigationActionResponse class

Constructors

CreateMitigationActionResponse({String? actionArn, String? actionId})
CreateMitigationActionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

actionArn → String?
The ARN for the new mitigation action.
final
actionId → String?
A unique identifier for the new mitigation action.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited