CreateOTAUpdateResponse class

Constructors

CreateOTAUpdateResponse({String? awsIotJobArn, String? awsIotJobId, String? otaUpdateArn, String? otaUpdateId, OTAUpdateStatus? otaUpdateStatus})
CreateOTAUpdateResponse.fromJson(Map<String, dynamic> json)
factory

Properties

awsIotJobArn → String?
The AWS IoT job ARN associated with the OTA update.
final
awsIotJobId → String?
The AWS IoT job ID associated with the OTA update.
final
hashCode → int
The hash code for this object.
no setterinherited
otaUpdateArn → String?
The OTA update ARN.
final
otaUpdateId → String?
The OTA update ID.
final
otaUpdateStatus → OTAUpdateStatus?
The OTA update status.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited