CreatePolicyResponse class

The output from the CreatePolicy operation.

Constructors

CreatePolicyResponse({String? policyArn, String? policyDocument, String? policyName, String? policyVersionId})
CreatePolicyResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
policyArn → String?
The policy ARN.
final
policyDocument → String?
The JSON document that describes the policy.
final
policyName → String?
The policy name.
final
policyVersionId → String?
The policy version ID.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited