CreateProvisioningClaimResponse class

Constructors

CreateProvisioningClaimResponse({String? certificateId, String? certificatePem, DateTime? expiration, KeyPair? keyPair})
CreateProvisioningClaimResponse.fromJson(Map<String, dynamic> json)
factory

Properties

certificateId → String?
The ID of the certificate.
final
certificatePem → String?
The provisioning claim certificate.
final
expiration → DateTime?
The provisioning claim expiration time.
final
hashCode → int
The hash code for this object.
no setterinherited
keyPair → KeyPair?
The provisioning claim key pair.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited