CreateProvisioningTemplateResponse class

Constructors

CreateProvisioningTemplateResponse({int? defaultVersionId, String? templateArn, String? templateName})
CreateProvisioningTemplateResponse.fromJson(Map<String, dynamic> json)
factory

Properties

defaultVersionId → int?
The default version of the fleet provisioning template.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateArn → String?
The ARN that identifies the provisioning template.
final
templateName → String?
The name of the fleet provisioning template.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited