CreateProvisioningTemplateVersionResponse class

Constructors

CreateProvisioningTemplateVersionResponse({bool? isDefaultVersion, String? templateArn, String? templateName, int? versionId})
CreateProvisioningTemplateVersionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDefaultVersion → bool?
True if the fleet provisioning template version is the default version, otherwise false.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateArn → String?
The ARN that identifies the provisioning template.
final
templateName → String?
The name of the fleet provisioning template.
final
versionId → int?
The version of the fleet provisioning template.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited