CreateRoleAliasResponse class

Constructors

CreateRoleAliasResponse({String? roleAlias, String? roleAliasArn})
CreateRoleAliasResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
roleAlias → String?
The role alias.
final
roleAliasArn → String?
The role alias ARN.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited