CreateThingGroupResponse class

Constructors

CreateThingGroupResponse({String? thingGroupArn, String? thingGroupId, String? thingGroupName})
CreateThingGroupResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thingGroupArn → String?
The thing group ARN.
final
thingGroupId → String?
The thing group ID.
final
thingGroupName → String?
The thing group name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited