CreateThingResponse class

The output of the CreateThing operation.

Constructors

CreateThingResponse({String? thingArn, String? thingId, String? thingName})
CreateThingResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thingArn → String?
The ARN of the new thing.
final
thingId → String?
The thing ID.
final
thingName → String?
The name of the new thing.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited