CustomCodeSigning class

Describes a custom method used to code sign a file.

Constructors

CustomCodeSigning({CodeSigningCertificateChain? certificateChain, String? hashAlgorithm, CodeSigningSignature? signature, String? signatureAlgorithm})
CustomCodeSigning.fromJson(Map<String, dynamic> json)
factory

Properties

certificateChain → CodeSigningCertificateChain?
The certificate chain.
final
hashAlgorithm → String?
The hash algorithm used to code sign the file.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature → CodeSigningSignature?
The signature for the file.
final
signatureAlgorithm → String?
The signature algorithm used to code sign the file.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited