DescribeDomainConfigurationResponse class

Constructors

DescribeDomainConfigurationResponse({AuthorizerConfig? authorizerConfig, String? domainConfigurationArn, String? domainConfigurationName, DomainConfigurationStatus? domainConfigurationStatus, String? domainName, DomainType? domainType, DateTime? lastStatusChangeDate, List<ServerCertificateSummary>? serverCertificates, ServiceType? serviceType})
DescribeDomainConfigurationResponse.fromJson(Map<String, dynamic> json)
factory

Properties

authorizerConfig → AuthorizerConfig?
An object that specifies the authorization service for a domain.
final
domainConfigurationArn → String?
The ARN of the domain configuration.
final
domainConfigurationName → String?
The name of the domain configuration.
final
domainConfigurationStatus → DomainConfigurationStatus?
A Boolean value that specifies the current state of the domain configuration.
final
domainName → String?
The name of the domain.
final
domainType → DomainType?
The type of the domain.
final
hashCode → int
The hash code for this object.
no setterinherited
lastStatusChangeDate → DateTime?
The date and time the domain configuration's status was last changed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverCertificates → List<ServerCertificateSummary>?
A list containing summary information about the server certificate included in the domain configuration.
final
serviceType → ServiceType?
The type of service delivered by the endpoint.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited