DescribeThingRegistrationTaskResponse class

Constructors

DescribeThingRegistrationTaskResponse({DateTime? creationDate, int? failureCount, String? inputFileBucket, String? inputFileKey, DateTime? lastModifiedDate, String? message, int? percentageProgress, String? roleArn, Status? status, int? successCount, String? taskId, String? templateBody})
DescribeThingRegistrationTaskResponse.fromJson(Map<String, dynamic> json)
factory

Properties

creationDate → DateTime?
The task creation date.
final
failureCount → int?
The number of things that failed to be provisioned.
final
hashCode → int
The hash code for this object.
no setterinherited
inputFileBucket → String?
The S3 bucket that contains the input file.
final
inputFileKey → String?
The input file key.
final
lastModifiedDate → DateTime?
The date when the task was last modified.
final
message → String?
The message.
final
percentageProgress → int?
The progress of the bulk provisioning task expressed as a percentage.
final
roleArn → String?
The role ARN that grants access to the input file bucket.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → Status?
The status of the bulk thing provisioning task.
final
successCount → int?
The number of things successfully provisioned.
final
taskId → String?
The task ID.
final
templateBody → String?
The task's template.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited