DetectMitigationActionsTaskStatistics class

The statistics of a mitigation action task.

Constructors

DetectMitigationActionsTaskStatistics({int? actionsExecuted, int? actionsFailed, int? actionsSkipped})
DetectMitigationActionsTaskStatistics.fromJson(Map<String, dynamic> json)
factory

Properties

actionsExecuted → int?
The actions that were performed.
final
actionsFailed → int?
The actions that failed.
final
actionsSkipped → int?
The actions that were skipped.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited