DetectMitigationActionsTaskSummary class

The summary of the mitigation action tasks.

Constructors

DetectMitigationActionsTaskSummary({List<MitigationAction>? actionsDefinition, bool? onlyActiveViolationsIncluded, bool? suppressedAlertsIncluded, DetectMitigationActionsTaskTarget? target, DateTime? taskEndTime, String? taskId, DateTime? taskStartTime, DetectMitigationActionsTaskStatistics? taskStatistics, DetectMitigationActionsTaskStatus? taskStatus, ViolationEventOccurrenceRange? violationEventOccurrenceRange})
DetectMitigationActionsTaskSummary.fromJson(Map<String, dynamic> json)
factory

Properties

actionsDefinition → List<MitigationAction>?
The definition of the actions.
final
hashCode → int
The hash code for this object.
no setterinherited
onlyActiveViolationsIncluded → bool?
Includes only active violations.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suppressedAlertsIncluded → bool?
Includes suppressed alerts.
final
target → DetectMitigationActionsTaskTarget?
Specifies the ML Detect findings to which the mitigation actions are applied.
final
taskEndTime → DateTime?
The date the task ended.
final
taskId → String?
The unique identifier of the task.
final
taskStartTime → DateTime?
The date the task started.
final
taskStatistics → DetectMitigationActionsTaskStatistics?
The statistics of a mitigation action task.
final
taskStatus → DetectMitigationActionsTaskStatus?
The status of the task.
final
violationEventOccurrenceRange → ViolationEventOccurrenceRange?
Specifies the time period of which violation events occurred between.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited