DetectMitigationActionsTaskTarget class

The target of a mitigation action task.

Constructors

DetectMitigationActionsTaskTarget({String? behaviorName, String? securityProfileName, List<String>? violationIds})
DetectMitigationActionsTaskTarget.fromJson(Map<String, dynamic> json)
factory

Properties

behaviorName → String?
The name of the behavior.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityProfileName → String?
The name of the security profile.
final
violationIds → List<String>?
The unique identifiers of the violations.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited