FileLocation class

The location of the OTA update.

Constructors

FileLocation({S3Location? s3Location, Stream? stream})
FileLocation.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Location → S3Location?
The location of the updated firmware in S3.
final
stream → Stream?
The stream that contains the OTA update.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited