GetIndexingConfigurationResponse class

Constructors

GetIndexingConfigurationResponse({ThingGroupIndexingConfiguration? thingGroupIndexingConfiguration, ThingIndexingConfiguration? thingIndexingConfiguration})
GetIndexingConfigurationResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thingGroupIndexingConfiguration → ThingGroupIndexingConfiguration?
The index configuration.
final
thingIndexingConfiguration → ThingIndexingConfiguration?
Thing indexing configuration.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited