GetLoggingOptionsResponse class

The output from the GetLoggingOptions operation.

Constructors

GetLoggingOptionsResponse({LogLevel? logLevel, String? roleArn})
GetLoggingOptionsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
logLevel → LogLevel?
The logging level.
final
roleArn → String?
The ARN of the IAM role that grants access.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited