GetPolicyVersionResponse class

The output from the GetPolicyVersion operation.

Constructors

GetPolicyVersionResponse({DateTime? creationDate, String? generationId, bool? isDefaultVersion, DateTime? lastModifiedDate, String? policyArn, String? policyDocument, String? policyName, String? policyVersionId})
GetPolicyVersionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

creationDate → DateTime?
The date the policy was created.
final
generationId → String?
The generation ID of the policy version.
final
hashCode → int
The hash code for this object.
no setterinherited
isDefaultVersion → bool?
Specifies whether the policy version is the default.
final
lastModifiedDate → DateTime?
The date the policy was last modified.
final
policyArn → String?
The policy ARN.
final
policyDocument → String?
The JSON document that describes the policy.
final
policyName → String?
The policy name.
final
policyVersionId → String?
The policy version ID.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited