GetStatisticsResponse class

Constructors

GetStatisticsResponse({Statistics? statistics})
GetStatisticsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statistics → Statistics?
The statistics returned by the Fleet Indexing service based on the query and aggregation field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited