GetTopicRuleResponse class

The output from the GetTopicRule operation.

Constructors

GetTopicRuleResponse({TopicRule? rule, String? ruleArn})
GetTopicRuleResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
rule → TopicRule?
The rule.
final
ruleArn → String?
The rule ARN.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited