GetV2LoggingOptionsResponse class

Constructors

GetV2LoggingOptionsResponse({LogLevel? defaultLogLevel, bool? disableAllLogs, String? roleArn})
GetV2LoggingOptionsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

defaultLogLevel → LogLevel?
The default log level.
final
disableAllLogs → bool?
Disables all logs.
final
hashCode → int
The hash code for this object.
no setterinherited
roleArn → String?
The IAM role ARN AWS IoT uses to write to your CloudWatch logs.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited