HttpContext class

Specifies the HTTP context to use for the test authorizer request.

Constructors

HttpContext({Map<String, String>? headers, String? queryString})

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>?
The header keys and values in an HTTP authorization request.
final
queryString → String?
The query string keys and values in an HTTP authorization request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited