HttpUrlDestinationSummary class

Information about an HTTP URL destination.

Constructors

HttpUrlDestinationSummary({String? confirmationUrl})
HttpUrlDestinationSummary.fromJson(Map<String, dynamic> json)
factory

Properties

confirmationUrl → String?
The URL used to confirm ownership of or access to the HTTP topic rule destination URL.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited