Job class

The Job object contains details about a job.

Constructors

Job({AbortConfig? abortConfig, String? comment, DateTime? completedAt, DateTime? createdAt, String? description, bool? forceCanceled, String? jobArn, JobExecutionsRolloutConfig? jobExecutionsRolloutConfig, String? jobId, JobProcessDetails? jobProcessDetails, DateTime? lastUpdatedAt, String? namespaceId, PresignedUrlConfig? presignedUrlConfig, String? reasonCode, JobStatus? status, TargetSelection? targetSelection, List<String>? targets, TimeoutConfig? timeoutConfig})
Job.fromJson(Map<String, dynamic> json)
factory

Properties

abortConfig → AbortConfig?
Configuration for criteria to abort the job.
final
comment → String?
If the job was updated, describes the reason for the update.
final
completedAt → DateTime?
The time, in seconds since the epoch, when the job was completed.
final
createdAt → DateTime?
The time, in seconds since the epoch, when the job was created.
final
description → String?
A short text description of the job.
final
forceCanceled → bool?
Will be true if the job was canceled with the optional force parameter set to true.
final
hashCode → int
The hash code for this object.
no setterinherited
jobArn → String?
An ARN identifying the job with format "arn:aws:iot:region:account:job/jobId".
final
jobExecutionsRolloutConfig → JobExecutionsRolloutConfig?
Allows you to create a staged rollout of a job.
final
jobId → String?
The unique identifier you assigned to this job when it was created.
final
jobProcessDetails → JobProcessDetails?
Details about the job process.
final
lastUpdatedAt → DateTime?
The time, in seconds since the epoch, when the job was last updated.
final
namespaceId → String?
The namespace used to indicate that a job is a customer-managed job.
final
presignedUrlConfig → PresignedUrlConfig?
Configuration for pre-signed S3 URLs.
final
reasonCode → String?
If the job was updated, provides the reason code for the update.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → JobStatus?
The status of the job, one of IN_PROGRESS, CANCELED, DELETION_IN_PROGRESS or COMPLETED.
final
targets → List<String>?
A list of IoT things and thing groups to which the job should be sent.
final
targetSelection → TargetSelection?
Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT). If continuous, the job may also be run on a thing when a change is detected in a target. For example, a job will run on a device when the thing representing the device is added to a target group, even after the job was completed by all things originally in the group.
final
timeoutConfig → TimeoutConfig?
Specifies the amount of time each device has to finish its execution of the job. A timer is started when the job execution status is set to IN_PROGRESS. If the job execution status is not set to another terminal state before the timer expires, it will be automatically set to TIMED_OUT.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited