JobExecution class

The job execution object represents the execution of a job on a particular device.

Constructors

JobExecution({int? approximateSecondsBeforeTimedOut, int? executionNumber, bool? forceCanceled, String? jobId, DateTime? lastUpdatedAt, DateTime? queuedAt, DateTime? startedAt, JobExecutionStatus? status, JobExecutionStatusDetails? statusDetails, String? thingArn, int? versionNumber})
JobExecution.fromJson(Map<String, dynamic> json)
factory

Properties

approximateSecondsBeforeTimedOut → int?
The estimated number of seconds that remain before the job execution status will be changed to TIMED_OUT. The timeout interval can be anywhere between 1 minute and 7 days (1 to 10080 minutes). The actual job execution timeout can occur up to 60 seconds later than the estimated duration. This value will not be included if the job execution has reached a terminal status.
final
executionNumber → int?
A string (consisting of the digits "0" through "9") which identifies this particular job execution on this particular device. It can be used in commands which return or update job execution information.
final
forceCanceled → bool?
Will be true if the job execution was canceled with the optional force parameter set to true.
final
hashCode → int
The hash code for this object.
no setterinherited
jobId → String?
The unique identifier you assigned to the job when it was created.
final
lastUpdatedAt → DateTime?
The time, in seconds since the epoch, when the job execution was last updated.
final
queuedAt → DateTime?
The time, in seconds since the epoch, when the job execution was queued.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startedAt → DateTime?
The time, in seconds since the epoch, when the job execution started.
final
status → JobExecutionStatus?
The status of the job execution (IN_PROGRESS, QUEUED, FAILED, SUCCEEDED, TIMED_OUT, CANCELED, or REJECTED).
final
statusDetails → JobExecutionStatusDetails?
A collection of name/value pairs that describe the status of the job execution.
final
thingArn → String?
The ARN of the thing on which the job execution is running.
final
versionNumber → int?
The version of the job execution. Job execution versions are incremented each time they are updated by a device.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited