JobProcessDetails class

The job process details.

Constructors

JobProcessDetails({int? numberOfCanceledThings, int? numberOfFailedThings, int? numberOfInProgressThings, int? numberOfQueuedThings, int? numberOfRejectedThings, int? numberOfRemovedThings, int? numberOfSucceededThings, int? numberOfTimedOutThings, List<String>? processingTargets})
JobProcessDetails.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
numberOfCanceledThings → int?
The number of things that cancelled the job.
final
numberOfFailedThings → int?
The number of things that failed executing the job.
final
numberOfInProgressThings → int?
The number of things currently executing the job.
final
numberOfQueuedThings → int?
The number of things that are awaiting execution of the job.
final
numberOfRejectedThings → int?
The number of things that rejected the job.
final
numberOfRemovedThings → int?
The number of things that are no longer scheduled to execute the job because they have been deleted or have been removed from the group that was a target of the job.
final
numberOfSucceededThings → int?
The number of things which successfully completed the job.
final
numberOfTimedOutThings → int?
The number of things whose job execution status is TIMED_OUT.
final
processingTargets → List<String>?
The target devices to which the job execution is being rolled out. This value will be null after the job execution has finished rolling out to all the target devices.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited