ListDomainConfigurationsResponse class

Constructors

ListDomainConfigurationsResponse({List<DomainConfigurationSummary>? domainConfigurations, String? nextMarker})
ListDomainConfigurationsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

domainConfigurations → List<DomainConfigurationSummary>?
A list of objects that contain summary information about the user's domain configurations.
final
hashCode → int
The hash code for this object.
no setterinherited
nextMarker → String?
The marker for the next set of results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited