ListJobExecutionsForJobResponse class

Constructors

ListJobExecutionsForJobResponse({List<JobExecutionSummaryForJob>? executionSummaries, String? nextToken})
ListJobExecutionsForJobResponse.fromJson(Map<String, dynamic> json)
factory

Properties

executionSummaries → List<JobExecutionSummaryForJob>?
A list of job execution summaries.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The token for the next set of results, or null if there are no additional results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited