ListTopicRuleDestinationsResponse class

Constructors

ListTopicRuleDestinationsResponse({List<TopicRuleDestinationSummary>? destinationSummaries, String? nextToken})
ListTopicRuleDestinationsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

destinationSummaries → List<TopicRuleDestinationSummary>?
Information about a topic rule destination.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The token to use to get the next set of results, or null if there are no additional results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited