ListTopicRulesResponse class

The output from the ListTopicRules operation.

Constructors

ListTopicRulesResponse({String? nextToken, List<TopicRuleListItem>? rules})
ListTopicRulesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The token to use to get the next set of results, or null if there are no additional results.
final
rules → List<TopicRuleListItem>?
The rules.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited