ListV2LoggingLevelsResponse class

Constructors

ListV2LoggingLevelsResponse({List<LogTargetConfiguration>? logTargetConfigurations, String? nextToken})
ListV2LoggingLevelsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
logTargetConfigurations → List<LogTargetConfiguration>?
The logging configuration for a target.
final
nextToken → String?
The token to use to get the next set of results, or null if there are no additional results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited