LogTargetConfiguration class

The target configuration.

Constructors

LogTargetConfiguration({LogLevel? logLevel, LogTarget? logTarget})
LogTargetConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
logLevel → LogLevel?
The logging level.
final
logTarget → LogTarget?
A log target
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited