LoggingOptionsPayload class

Describes the logging options payload.

Constructors

LoggingOptionsPayload({required String roleArn, LogLevel? logLevel})

Properties

hashCode → int
The hash code for this object.
no setterinherited
logLevel → LogLevel?
The log level.
final
roleArn → String
The ARN of the IAM role that grants access.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited