MitigationAction class

Describes which changes should be applied as part of a mitigation action.

Constructors

MitigationAction({MitigationActionParams? actionParams, String? id, String? name, String? roleArn})
MitigationAction.fromJson(Map<String, dynamic> json)
factory

Properties

actionParams → MitigationActionParams?
The set of parameters for this mitigation action. The parameters vary, depending on the kind of action you apply.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
A unique identifier for the mitigation action.
final
name → String?
A user-friendly name for the mitigation action.
final
roleArn → String?
The IAM role ARN used to apply this mitigation action.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited