OTAUpdateFile class

Describes a file to be associated with an OTA update.

Constructors

OTAUpdateFile({Map<String, String>? attributes, CodeSigning? codeSigning, FileLocation? fileLocation, String? fileName, int? fileType, String? fileVersion})
OTAUpdateFile.fromJson(Map<String, dynamic> json)
factory

Properties

attributes → Map<String, String>?
A list of name/attribute pairs.
final
codeSigning → CodeSigning?
The code signing method of the file.
final
fileLocation → FileLocation?
The location of the updated firmware.
final
fileName → String?
The name of the file.
final
fileType → int?
An integer value you can include in the job document to allow your devices to identify the type of file received from the cloud.
final
fileVersion → String?
The file version.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited