PolicyVersion class

Describes a policy version.

Constructors

PolicyVersion({DateTime? createDate, bool? isDefaultVersion, String? versionId})
PolicyVersion.fromJson(Map<String, dynamic> json)
factory

Properties

createDate → DateTime?
The date and time the policy was created.
final
hashCode → int
The hash code for this object.
no setterinherited
isDefaultVersion → bool?
Specifies whether the policy version is the default.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionId → String?
The policy version ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited