PolicyVersionIdentifier class

Information about the version of the policy associated with the resource.

Constructors

PolicyVersionIdentifier({String? policyName, String? policyVersionId})
PolicyVersionIdentifier.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
policyName → String?
The name of the policy.
final
policyVersionId → String?
The ID of the version of the policy associated with the resource.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited