ResourceIdentifier class

Information that identifies the noncompliant resource.

Constructors

ResourceIdentifier({String? account, String? caCertificateId, String? clientId, String? cognitoIdentityPoolId, String? deviceCertificateId, String? iamRoleArn, PolicyVersionIdentifier? policyVersionIdentifier, String? roleAliasArn})
ResourceIdentifier.fromJson(Map<String, dynamic> json)
factory

Properties

account → String?
The account with which the resource is associated.
final
caCertificateId → String?
The ID of the CA certificate used to authorize the certificate.
final
clientId → String?
The client ID.
final
cognitoIdentityPoolId → String?
The ID of the Amazon Cognito identity pool.
final
deviceCertificateId → String?
The ID of the certificate attached to the resource.
final
hashCode → int
The hash code for this object.
no setterinherited
iamRoleArn → String?
The ARN of the IAM role that has overly permissive actions.
final
policyVersionIdentifier → PolicyVersionIdentifier?
The version of the policy associated with the resource.
final
roleAliasArn → String?
The ARN of the role alias that has overly permissive actions.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited