S3Destination class

Describes the location of updated firmware in S3.

Constructors

S3Destination({String? bucket, String? prefix})
S3Destination.fromJson(Map<String, dynamic> json)
factory

Properties

bucket → String?
The S3 bucket that contains the updated firmware.
final
hashCode → int
The hash code for this object.
no setterinherited
prefix → String?
The S3 prefix.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited