SecurityProfileTargetMapping class

Information about a security profile and the target associated with it.

Constructors

SecurityProfileTargetMapping({SecurityProfileIdentifier? securityProfileIdentifier, SecurityProfileTarget? target})
SecurityProfileTargetMapping.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityProfileIdentifier → SecurityProfileIdentifier?
Information that identifies the security profile.
final
target → SecurityProfileTarget?
Information about the target (thing group) associated with the security profile.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited