Statistics class

A map of key-value pairs for all supported statistics. Currently, only count is supported.

Constructors

Statistics({double? average, int? count, double? maximum, double? minimum, double? stdDeviation, double? sum, double? sumOfSquares, double? variance})
Statistics.fromJson(Map<String, dynamic> json)
factory

Properties

average → double?
The average of the aggregated field values.
final
count → int?
The count of things that match the query.
final
hashCode → int
The hash code for this object.
no setterinherited
maximum → double?
The maximum aggregated field value.
final
minimum → double?
The minimum aggregated field value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stdDeviation → double?
The standard deviation of the aggregated field values.
final
sum → double?
The sum of the aggregated field values.
final
sumOfSquares → double?
The sum of the squares of the aggregated field values.
final
variance → double?
The variance of the aggregated field values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited