StepFunctionsAction class

Starts execution of a Step Functions state machine.

Constructors

StepFunctionsAction({required String roleArn, required String stateMachineName, String? executionNamePrefix})
StepFunctionsAction.fromJson(Map<String, dynamic> json)
factory

Properties

executionNamePrefix → String?
(Optional) A name will be given to the state machine execution consisting of this prefix followed by a UUID. Step Functions automatically creates a unique name for each state machine execution if one is not provided.
final
hashCode → int
The hash code for this object.
no setterinherited
roleArn → String
The ARN of the role that grants IoT permission to start execution of a state machine ("Action":"states:StartExecution").
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateMachineName → String
The name of the Step Functions state machine whose execution will be started.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited