Stream class

Describes a group of files that can be streamed.

Constructors

Stream({int? fileId, String? streamId})
Stream.fromJson(Map<String, dynamic> json)
factory

Properties

fileId → int?
The ID of a file associated with a stream.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamId → String?
The stream ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited