StreamInfo class

Information about a stream.

Constructors

StreamInfo({DateTime? createdAt, String? description, List<StreamFile>? files, DateTime? lastUpdatedAt, String? roleArn, String? streamArn, String? streamId, int? streamVersion})
StreamInfo.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → DateTime?
The date when the stream was created.
final
description → String?
The description of the stream.
final
files → List<StreamFile>?
The files to stream.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedAt → DateTime?
The date when the stream was last updated.
final
roleArn → String?
An IAM role AWS IoT assumes to access your S3 files.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamArn → String?
The stream ARN.
final
streamId → String?
The stream ID.
final
streamVersion → int?
The stream version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited