TaskStatistics class

Statistics for the checks performed during the audit.

Constructors

TaskStatistics({int? canceledChecks, int? compliantChecks, int? failedChecks, int? inProgressChecks, int? nonCompliantChecks, int? totalChecks, int? waitingForDataCollectionChecks})
TaskStatistics.fromJson(Map<String, dynamic> json)
factory

Properties

canceledChecks → int?
The number of checks that did not run because the audit was canceled.
final
compliantChecks → int?
The number of checks that found compliant resources.
final
failedChecks → int?
The number of checks.
final
hashCode → int
The hash code for this object.
no setterinherited
inProgressChecks → int?
The number of checks in progress.
final
nonCompliantChecks → int?
The number of checks that found noncompliant resources.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalChecks → int?
The number of checks in this audit.
final
waitingForDataCollectionChecks → int?
The number of checks waiting for data collection.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited