TaskStatisticsForAuditCheck class

Provides summary counts of how many tasks for findings are in a particular state. This information is included in the response from DescribeAuditMitigationActionsTask.

Constructors

TaskStatisticsForAuditCheck({int? canceledFindingsCount, int? failedFindingsCount, int? skippedFindingsCount, int? succeededFindingsCount, int? totalFindingsCount})
TaskStatisticsForAuditCheck.fromJson(Map<String, dynamic> json)
factory

Properties

canceledFindingsCount → int?
The number of findings to which the mitigation action task was canceled when applied.
final
failedFindingsCount → int?
The number of findings for which at least one of the actions failed when applied.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skippedFindingsCount → int?
The number of findings skipped because of filter conditions provided in the parameters to the command.
final
succeededFindingsCount → int?
The number of findings for which all mitigation actions succeeded when applied.
final
totalFindingsCount → int?
The total number of findings to which a task is being applied.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited