TestInvokeAuthorizerResponse class

Constructors

TestInvokeAuthorizerResponse({int? disconnectAfterInSeconds, bool? isAuthenticated, List<String>? policyDocuments, String? principalId, int? refreshAfterInSeconds})
TestInvokeAuthorizerResponse.fromJson(Map<String, dynamic> json)
factory

Properties

disconnectAfterInSeconds → int?
The number of seconds after which the connection is terminated.
final
hashCode → int
The hash code for this object.
no setterinherited
isAuthenticated → bool?
True if the token is authenticated, otherwise false.
final
policyDocuments → List<String>?
IAM policy documents.
final
principalId → String?
The principal ID.
final
refreshAfterInSeconds → int?
The number of seconds after which the temporary credentials are refreshed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited