ThingConnectivity class

The connectivity status of the thing.

Constructors

ThingConnectivity({bool? connected, int? timestamp})
ThingConnectivity.fromJson(Map<String, dynamic> json)
factory

Properties

connected → bool?
True if the thing is connected to the AWS IoT service; false if it is not connected.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int?
The epoch time (in milliseconds) when the thing last connected or disconnected. If the thing has been disconnected for more than a few weeks, the time value might be missing.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited