ThingGroupMetadata class

Thing group metadata.

Constructors

ThingGroupMetadata({DateTime? creationDate, String? parentGroupName, List<GroupNameAndArn>? rootToParentThingGroups})
ThingGroupMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

creationDate → DateTime?
The UNIX timestamp of when the thing group was created.
final
hashCode → int
The hash code for this object.
no setterinherited
parentGroupName → String?
The parent thing group name.
final
rootToParentThingGroups → List<GroupNameAndArn>?
The root parent thing group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited