ThingIndexingConfiguration class

The thing indexing configuration. For more information, see Managing Thing Indexing.

Constructors

ThingIndexingConfiguration({required ThingIndexingMode thingIndexingMode, List<Field>? customFields, List<Field>? managedFields, ThingConnectivityIndexingMode? thingConnectivityIndexingMode})
ThingIndexingConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

customFields → List<Field>?
Contains custom field names and their data type.
final
hashCode → int
The hash code for this object.
no setterinherited
managedFields → List<Field>?
Contains fields that are indexed and whose types are already known by the Fleet Indexing service.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thingConnectivityIndexingMode → ThingConnectivityIndexingMode?
Thing connectivity indexing mode. Valid values are:
final
thingIndexingMode → ThingIndexingMode
Thing indexing mode. Valid values are:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited