ThingTypeMetadata class

The ThingTypeMetadata contains additional information about the thing type including: creation date and time, a value indicating whether the thing type is deprecated, and a date and time when time was deprecated.

Constructors

ThingTypeMetadata({DateTime? creationDate, bool? deprecated, DateTime? deprecationDate})
ThingTypeMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

creationDate → DateTime?
The date and time when the thing type was created.
final
deprecated → bool?
Whether the thing type is deprecated. If true, no new things could be associated with this type.
final
deprecationDate → DateTime?
The date and time when the thing type was deprecated.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited