ThingTypeProperties class

The ThingTypeProperties contains information about the thing type including: a thing type description, and a list of searchable thing attribute names.

Constructors

ThingTypeProperties({List<String>? searchableAttributes, String? thingTypeDescription})
ThingTypeProperties.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchableAttributes → List<String>?
A list of searchable thing attribute names.
final
thingTypeDescription → String?
The description of the thing type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited