TimestreamAction class

The Timestream rule action writes attributes (measures) from an MQTT message into an Amazon Timestream table. For more information, see the Timestream topic rule action documentation.

Constructors

TimestreamAction({required String databaseName, required List<TimestreamDimension> dimensions, required String roleArn, required String tableName, TimestreamTimestamp? timestamp})
TimestreamAction.fromJson(Map<String, dynamic> json)
factory

Properties

databaseName → String
The name of an Amazon Timestream database.
final
dimensions → List<TimestreamDimension>
Metadata attributes of the time series that are written in each measure record.
final
hashCode → int
The hash code for this object.
no setterinherited
roleArn → String
The ARN of the role that grants permission to write to the Amazon Timestream database table.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableName → String
The name of the database table into which to write the measure records.
final
timestamp → TimestreamTimestamp?
Specifies an application-defined value to replace the default value assigned to the Timestream record's timestamp in the time column.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited