TimestreamTimestamp class

Describes how to interpret an application-defined timestamp value from an MQTT message payload and the precision of that value.

Constructors

TimestreamTimestamp({required String unit, required String value})
TimestreamTimestamp.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit → String
The precision of the timestamp value that results from the expression described in value.
final
value → String
An expression that returns a long epoch time value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited