TopicRule class

Describes a rule.

Constructors

TopicRule({List<Action>? actions, String? awsIotSqlVersion, DateTime? createdAt, String? description, Action? errorAction, bool? ruleDisabled, String? ruleName, String? sql})
TopicRule.fromJson(Map<String, dynamic> json)
factory

Properties

actions → List<Action>?
The actions associated with the rule.
final
awsIotSqlVersion → String?
The version of the SQL rules engine to use when evaluating the rule.
final
createdAt → DateTime?
The date and time the rule was created.
final
description → String?
The description of the rule.
final
errorAction → Action?
The action to perform when an error occurs.
final
hashCode → int
The hash code for this object.
no setterinherited
ruleDisabled → bool?
Specifies whether the rule is disabled.
final
ruleName → String?
The name of the rule.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sql → String?
The SQL statement used to query the topic. When using a SQL query with multiple lines, be sure to escape the newline characters.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited