TopicRuleDestination class

A topic rule destination.

Constructors

TopicRuleDestination({String? arn, DateTime? createdAt, HttpUrlDestinationProperties? httpUrlProperties, DateTime? lastUpdatedAt, TopicRuleDestinationStatus? status, String? statusReason, VpcDestinationProperties? vpcProperties})
TopicRuleDestination.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The topic rule destination URL.
final
createdAt → DateTime?
The date and time when the topic rule destination was created.
final
hashCode → int
The hash code for this object.
no setterinherited
httpUrlProperties → HttpUrlDestinationProperties?
Properties of the HTTP URL.
final
lastUpdatedAt → DateTime?
The date and time when the topic rule destination was last updated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TopicRuleDestinationStatus?
The status of the topic rule destination. Valid values are:
final
statusReason → String?
Additional details or reason why the topic rule destination is in the current status.
final
vpcProperties → VpcDestinationProperties?
Properties of the virtual private cloud (VPC) connection.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited