TopicRuleDestinationConfiguration class

Configuration of the topic rule destination.

Constructors

TopicRuleDestinationConfiguration({HttpUrlDestinationConfiguration? httpUrlConfiguration, VpcDestinationConfiguration? vpcConfiguration})

Properties

hashCode → int
The hash code for this object.
no setterinherited
httpUrlConfiguration → HttpUrlDestinationConfiguration?
Configuration of the HTTP URL.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpcConfiguration → VpcDestinationConfiguration?
Configuration of the virtual private cloud (VPC) connection.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited