TopicRuleListItem class

Describes a rule.

Constructors

TopicRuleListItem({DateTime? createdAt, String? ruleArn, bool? ruleDisabled, String? ruleName, String? topicPattern})
TopicRuleListItem.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → DateTime?
The date and time the rule was created.
final
hashCode → int
The hash code for this object.
no setterinherited
ruleArn → String?
The rule ARN.
final
ruleDisabled → bool?
Specifies whether the rule is disabled.
final
ruleName → String?
The name of the rule.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topicPattern → String?
The pattern for the topic names that apply.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited