TopicRulePayload class

Describes a rule.

Constructors

TopicRulePayload({required List<Action> actions, required String sql, String? awsIotSqlVersion, String? description, Action? errorAction, bool? ruleDisabled})

Properties

actions → List<Action>
The actions associated with the rule.
final
awsIotSqlVersion → String?
The version of the SQL rules engine to use when evaluating the rule.
final
description → String?
The description of the rule.
final
errorAction → Action?
The action to take when an error occurs.
final
hashCode → int
The hash code for this object.
no setterinherited
ruleDisabled → bool?
Specifies whether the rule is disabled.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sql → String
The SQL statement used to query the topic. For more information, see AWS IoT SQL Reference in the AWS IoT Developer Guide.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited