TransferData class

Data used to transfer a certificate to an AWS account.

Constructors

TransferData({DateTime? acceptDate, DateTime? rejectDate, String? rejectReason, DateTime? transferDate, String? transferMessage})
TransferData.fromJson(Map<String, dynamic> json)
factory

Properties

acceptDate → DateTime?
The date the transfer was accepted.
final
hashCode → int
The hash code for this object.
no setterinherited
rejectDate → DateTime?
The date the transfer was rejected.
final
rejectReason → String?
The reason why the transfer was rejected.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transferDate → DateTime?
The date the transfer took place.
final
transferMessage → String?
The transfer message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited