UpdateCustomMetricResponse class

Constructors

UpdateCustomMetricResponse({DateTime? creationDate, String? displayName, DateTime? lastModifiedDate, String? metricArn, String? metricName, CustomMetricType? metricType})
UpdateCustomMetricResponse.fromJson(Map<String, dynamic> json)
factory

Properties

creationDate → DateTime?
The creation date of the custom metric in milliseconds since epoch.
final
displayName → String?
A friendly name in the console for the custom metric
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedDate → DateTime?
The time the custom metric was last modified in milliseconds since epoch.
final
metricArn → String?
The Amazon Resource Number (ARN) of the custom metric.
final
metricName → String?
The name of the custom metric.
final
metricType → CustomMetricType?
The type of the custom metric. Types include string-list, ip-address-list, number-list, and number.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited