UpdateDimensionResponse class

Constructors

UpdateDimensionResponse({String? arn, DateTime? creationDate, DateTime? lastModifiedDate, String? name, List<String>? stringValues, DimensionType? type})
UpdateDimensionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN)of the created dimension.
final
creationDate → DateTime?
The date and time, in milliseconds since epoch, when the dimension was initially created.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedDate → DateTime?
The date and time, in milliseconds since epoch, when the dimension was most recently updated.
final
name → String?
A unique identifier for the dimension.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValues → List<String>?
The value or list of values used to scope the dimension. For example, for topic filters, this is the pattern used to match the MQTT topic name.
final
type → DimensionType?
The type of the dimension.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited