UpdateSecurityProfileResponse class

Constructors

UpdateSecurityProfileResponse({List<String>? additionalMetricsToRetain, List<MetricToRetain>? additionalMetricsToRetainV2, Map<AlertTargetType, AlertTarget>? alertTargets, List<Behavior>? behaviors, DateTime? creationDate, DateTime? lastModifiedDate, String? securityProfileArn, String? securityProfileDescription, String? securityProfileName, int? version})
UpdateSecurityProfileResponse.fromJson(Map<String, dynamic> json)
factory

Properties

additionalMetricsToRetain → List<String>?
Please use UpdateSecurityProfileResponse$additionalMetricsToRetainV2 instead.
final
additionalMetricsToRetainV2 → List<MetricToRetain>?
A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile's behaviors, but it is also retained for any metric specified here. Can be used with custom metrics; cannot be used with dimensions.
final
alertTargets → Map<AlertTargetType, AlertTarget>?
Where the alerts are sent. (Alerts are always sent to the console.)
final
behaviors → List<Behavior>?
Specifies the behaviors that, when violated by a device (thing), cause an alert.
final
creationDate → DateTime?
The time the security profile was created.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedDate → DateTime?
The time the security profile was last modified.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityProfileArn → String?
The ARN of the security profile that was updated.
final
securityProfileDescription → String?
The description of the security profile.
final
securityProfileName → String?
The name of the security profile that was updated.
final
version → int?
The updated version of the security profile.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited