UpdateStreamResponse class

Constructors

UpdateStreamResponse({String? description, String? streamArn, String? streamId, int? streamVersion})
UpdateStreamResponse.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
A description of the stream.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamArn → String?
The stream ARN.
final
streamId → String?
The stream ID.
final
streamVersion → int?
The stream version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited