VpcDestinationConfiguration class

The configuration information for a virtual private cloud (VPC) destination.

Constructors

VpcDestinationConfiguration({required String roleArn, required List<String> subnetIds, required String vpcId, List<String>? securityGroups})

Properties

hashCode → int
The hash code for this object.
no setterinherited
roleArn → String
The ARN of a role that has permission to create and attach to elastic network interfaces (ENIs).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityGroups → List<String>?
The security groups of the VPC destination.
final
subnetIds → List<String>
The subnet IDs of the VPC destination.
final
vpcId → String
The ID of the VPC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited